define(
//begin v1.x content
({
	smiley: "插入表情图标",
	emoticonSmile: "微笑",
	emoticonLaughing: "大笑",
	emoticonWink: "眨眼",
	emoticonGrin: "咧着嘴笑",
	emoticonCool: "酷",
	emoticonAngry: "愤怒",
	emoticonHalf: "左右为难",
	emoticonEyebrow: "挑眉",
	emoticonFrown: "皱眉",
	emoticonShy: "害羞",
	emoticonGoofy: "傻了",
	emoticonOops: "oops",
	emoticonTongue: "吐舌",
	emoticonIdea: "思考",
	emoticonYes: "点头",
	emoticonNo: "摇头",
	emoticonAngel: "天使",
	emoticonCrying: "哭泣",
	emoticonHappy: "高兴"
})

//end v1.x content
);
